@@ -63,7 +63,11 @@ def _get_zfs_path(config):
     if not config.ZFS_PATH_VOLUMES:
         abort(
             "Please configure the snapshot root folder for docker "
-            "snapshots in ZFS_PATH_VOLUMES"
+            "snapshots in ZFS_PATH_VOLUMES.\n"
+            "Example: pool1/docker/volumes\n"
+            "You must make sure that a filesystem exists for docker/volumes."
+            "If poolname is pool1 and mounted on /var/lib/docker you do: \n"
+            "zfs create pool1/volumes\n"
         )
     path = config.ZFS_PATH_VOLUMES + "/" + __get_postgres_volume_name(config)
     return path
@@ -171,7 +175,6 @@ def _turn_into_subvolume(config):
     zfs = search_env_path("zfs")
     fullpath = _get_path(config)
     fullpath_zfs = _get_zfs_path(config)
-    import pudb;pudb.set_trace()
     if __is_zfs_fs(fullpath_zfs):
         # is zfs - do nothing
         return
@@ -327,4 +330,4 @@ def clear_all(config):
     _try_umount(config)
     diskpath = translate_poolPath_to_fullPath(zfs_full_path)
     if __is_zfs_fs(diskpath):
-        subprocess.check_call(["sudo", zfs, "destroy", "-r", zfs_full_path])
+        subprocess.check_call(["sudo", zfs, "destroy", "-r", zfs_full_path])
\ No newline at end of file
